==> jc-1.4.0.tar.gz: jasmin/Scanner.h <==
// class jasmin.Scanner

// class file dependencies
// @dep_class 2527807abd2ebf25 jasmin_Scanner
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_jasmin_Scanner_H_
#define _JC_jasmin_Scanner_H_

// Forward structure declarations
struct _jc_java_io_InputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_lang_StringBuffer$object;
struct _jc_java_util_Hashtable$object;
struct _jc_java__5fcup_runtime_Symbol$object;

// Typedefs
typedef struct _jc_jasmin_Scanner$sub_refs	_jc_jasmin_Scanner$sub_refs;
typedef struct _jc_jasmin_Scanner$sub_nonrefs	_jc_jasmin_Scanner$sub_nonrefs;
typedef struct _jc_jasmin_Scanner$refs	_jc_jasmin_Scanner$refs;
typedef struct _jc_jasmin_Scanner$nonrefs	_jc_jasmin_Scanner$nonrefs;
typedef struct _jc_jasmin_Scanner$object	_jc_jasmin_Scanner$object;

typedef struct _jc_jasmin_Scanner$fields_struct	_jc_jasmin_Scanner$fields_struct;
typedef const struct _jc_jasmin_Scanner$vmethods	_jc_jasmin_Scanner$vmethods;
typedef const struct _jc_jasmin_Scanner$vtable	_jc_jasmin_Scanner$vtable;
typedef const struct _jc_jasmin_Scanner$vtype	_jc_jasmin_Scanner$vtype;

// Class fields structure
struct _jc_jasmin_Scanner$fields_struct {
	struct _jc_java_lang_String$object	*SEPARATORS;
	struct _jc_java_lang_String$object	*WHITESPACE;
	jint	BIGNUM;
};
extern _jc_jasmin_Scanner$fields_struct _jc_jasmin_Scanner$class_fields;

// Constructors
extern void _jc_jasmin_Scanner$method$_init$3887600c17c5e554(_jc_env *, struct _jc_jasmin_Scanner$object *, struct _jc_java_io_InputStream$object *);

// Virtual methods
extern void _jc_jasmin_Scanner$method$advance$3cb6335d931ec4c0(_jc_env *, struct _jc_jasmin_Scanner$object *);
extern struct _jc_java__5fcup_runtime_Symbol$object *_jc_jasmin_Scanner$method$next__5ftoken$d2d2cf57fe6820fc(_jc_env *, struct _jc_jasmin_Scanner$object *);
extern jint _jc_jasmin_Scanner$method$readOctal$3983742c1b52ee5a(_jc_env *, struct _jc_jasmin_Scanner$object *, jint);

// Virtual method descriptors
extern _jc_method _jc_jasmin_Scanner$method_info$advance$3cb6335d931ec4c0;
extern _jc_method _jc_jasmin_Scanner$method_info$next__5ftoken$d2d2cf57fe6820fc;
extern _jc_method _jc_jasmin_Scanner$method_info$readOctal$3983742c1b52ee5a;

// Static methods
extern jboolean _jc_jasmin_Scanner$method$separator$5a13f66a5a604794(_jc_env *, jint);
extern jboolean _jc_jasmin_Scanner$method$whitespace$fdec05286d1d2f0f(_jc_env *, jint);

// Virtual methods structure
struct _jc_jasmin_Scanner$vmethods {
	void	(*advance$3cb6335d931ec4c0)(_jc_env *, struct _jc_jasmin_Scanner$object *);
	struct _jc_java__5fcup_runtime_Symbol$object	*(*next__5ftoken$d2d2cf57fe6820fc)(_jc_env *, struct _jc_jasmin_Scanner$object *);
	jint	(*readOctal$3983742c1b52ee5a)(_jc_env *, struct _jc_jasmin_Scanner$object *, jint);
};

// Vtable
struct _jc_jasmin_Scanner$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_jasmin_Scanner$vmethods	jasmin_Scanner;
};

// Vtype
struct _jc_jasmin_Scanner$vtype {
	_jc_type			type;
	_jc_jasmin_Scanner$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_jasmin_Scanner$sub_refs {
	struct _jc_java_io_InputStream$object	*inp;
	_jc_char_array	*chars;
	_jc_char_array	*secondChars;
	_jc_char_array	*unicodeBuffer;
	struct _jc_java_lang_StringBuffer$object	*line;
	struct _jc_java_util_Hashtable$object	*dict;
};

// Reference instance fields (object)
struct _jc_jasmin_Scanner$refs {
    _jc_jasmin_Scanner$sub_refs	jasmin_Scanner;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_jasmin_Scanner$sub_nonrefs {
	jint	next__5fchar;
	jboolean	is__5ffirst__5fsep;
	jint	line__5fnum;
	jint	char__5fnum;
	jint	token__5fline__5fnum;
};

// Non-reference instance fields (object)
struct _jc_jasmin_Scanner$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_jasmin_Scanner$sub_nonrefs	jasmin_Scanner;
};

// Object instance structure
struct _jc_jasmin_Scanner$object {
	_jc_jasmin_Scanner$refs	refs[0];
	_jc_word		lockword;
	_jc_jasmin_Scanner$vtype	*vtype;
	_jc_jasmin_Scanner$nonrefs	nonrefs;
};

// Type structure
extern _jc_jasmin_Scanner$vtype _jc_jasmin_Scanner$type;

// Array types class info structures
_JC_DECL_ARRAYS(jasmin_Scanner, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_jasmin_Scanner$class_object;

#endif	/* _JC_jasmin_Scanner_H_ */

==> jc-1.4.6.tar.gz: jasmin/Scanner.h <==
// class jasmin.Scanner

// class file dependencies
// @dep_class 2527807abd2ebf25 jasmin_Scanner
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_jasmin_Scanner_H_
#define _JC_jasmin_Scanner_H_

// Forward structure declarations
struct _jc_java_io_InputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_lang_StringBuffer$object;
struct _jc_java_util_Hashtable$object;
struct _jc_java__5fcup_runtime_Symbol$object;

// Typedefs
typedef struct _jc_jasmin_Scanner$sub_refs	_jc_jasmin_Scanner$sub_refs;
typedef struct _jc_jasmin_Scanner$sub_nonrefs	_jc_jasmin_Scanner$sub_nonrefs;
typedef struct _jc_jasmin_Scanner$refs	_jc_jasmin_Scanner$refs;
typedef struct _jc_jasmin_Scanner$nonrefs	_jc_jasmin_Scanner$nonrefs;
typedef struct _jc_jasmin_Scanner$object	_jc_jasmin_Scanner$object;

typedef struct _jc_jasmin_Scanner$fields_struct	_jc_jasmin_Scanner$fields_struct;
typedef const struct _jc_jasmin_Scanner$vmethods	_jc_jasmin_Scanner$vmethods;
typedef const struct _jc_jasmin_Scanner$vtable	_jc_jasmin_Scanner$vtable;
typedef const struct _jc_jasmin_Scanner$vtype	_jc_jasmin_Scanner$vtype;

// Class fields structure
struct _jc_jasmin_Scanner$fields_struct {
	struct _jc_java_lang_String$object	*SEPARATORS;
	struct _jc_java_lang_String$object	*WHITESPACE;
	jint	BIGNUM;
};
extern _jc_jasmin_Scanner$fields_struct _jc_jasmin_Scanner$class_fields;

// Constructors
extern void _jc_jasmin_Scanner$method$_init$3887600c17c5e554(_jc_env *, struct _jc_jasmin_Scanner$object *, struct _jc_java_io_InputStream$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_jasmin_Scanner$method$advance$3cb6335d931ec4c0(_jc_env *, struct _jc_jasmin_Scanner$object *) _JC_JCNI_ATTR;
extern struct _jc_java__5fcup_runtime_Symbol$object *_jc_jasmin_Scanner$method$next__5ftoken$d2d2cf57fe6820fc(_jc_env *, struct _jc_jasmin_Scanner$object *) _JC_JCNI_ATTR;
extern jint _jc_jasmin_Scanner$method$readOctal$3983742c1b52ee5a(_jc_env *, struct _jc_jasmin_Scanner$object *, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_jasmin_Scanner$method_info$advance$3cb6335d931ec4c0;
extern _jc_method _jc_jasmin_Scanner$method_info$next__5ftoken$d2d2cf57fe6820fc;
extern _jc_method _jc_jasmin_Scanner$method_info$readOctal$3983742c1b52ee5a;

// Static methods
extern jboolean _jc_jasmin_Scanner$method$separator$5a13f66a5a604794(_jc_env *, jint) _JC_JCNI_ATTR;
extern jboolean _jc_jasmin_Scanner$method$whitespace$fdec05286d1d2f0f(_jc_env *, jint) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_jasmin_Scanner$vmethods {
	void	(*advance$3cb6335d931ec4c0)(_jc_env *, struct _jc_jasmin_Scanner$object *) _JC_JCNI_ATTR;
	struct _jc_java__5fcup_runtime_Symbol$object	*(*next__5ftoken$d2d2cf57fe6820fc)(_jc_env *, struct _jc_jasmin_Scanner$object *) _JC_JCNI_ATTR;
	jint	(*readOctal$3983742c1b52ee5a)(_jc_env *, struct _jc_jasmin_Scanner$object *, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_jasmin_Scanner$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_jasmin_Scanner$vmethods	jasmin_Scanner;
};

// Vtype
struct _jc_jasmin_Scanner$vtype {
	_jc_type			type;
	_jc_jasmin_Scanner$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_jasmin_Scanner$sub_refs {
	struct _jc_java_io_InputStream$object	*inp;
	_jc_char_array	*chars;
	_jc_char_array	*secondChars;
	_jc_char_array	*unicodeBuffer;
	struct _jc_java_lang_StringBuffer$object	*line;
	struct _jc_java_util_Hashtable$object	*dict;
};

// Reference instance fields (object)
struct _jc_jasmin_Scanner$refs {
    _jc_jasmin_Scanner$sub_refs	jasmin_Scanner;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_jasmin_Scanner$sub_nonrefs {
	jint	next__5fchar;
	jboolean	is__5ffirst__5fsep;
	jint	line__5fnum;
	jint	char__5fnum;
	jint	token__5fline__5fnum;
};

// Non-reference instance fields (object)
struct _jc_jasmin_Scanner$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_jasmin_Scanner$sub_nonrefs	jasmin_Scanner;
};

// Object instance structure
struct _jc_jasmin_Scanner$object {
	_jc_jasmin_Scanner$refs	refs[0];
	_jc_word		lockword;
	_jc_jasmin_Scanner$vtype	*vtype;
	_jc_jasmin_Scanner$nonrefs	nonrefs;
};

// Type structure
extern _jc_jasmin_Scanner$vtype _jc_jasmin_Scanner$type;

// Array types class info structures
_JC_DECL_ARRAYS(jasmin_Scanner, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_jasmin_Scanner$class_object;

#endif	/* _JC_jasmin_Scanner_H_ */
